/*
 * Copyright (C) 2010 SHARP Corporation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.co.sharp.android.samples.pedometer;

import jp.co.sharp.android.hardware.Pedometer;
import android.app.Activity;
import android.os.Bundle;
import android.widget.TextView;

/**
 * インストールしている機種でサポートされている歩数計のデータ種類を一覧表示するActivity
 * 表示のみでチェックや選択はできない。
 */
public class SamplePedometerSupportDataList extends Activity {

    /**
     * 画面起動時に呼ばれる。
     * onCreate()をオーバーライドしている。
     * @param bundle Bundle
     */
    @Override
    public void onCreate(Bundle bundle) {
        super.onCreate(bundle);

        setContentView(R.layout.support_data_list);

        TextView dataName = (TextView)findViewById(R.id.supportDataListName);
        TextView dataParam = (TextView)findViewById(R.id.supportDataListParam);

        // サポートの有無をチェックする項目を格納する
        final String[] key = {
                Pedometer.AEROBICS_STEPS,
                Pedometer.CALORIE,
                Pedometer.DISTANCE,
                Pedometer.EXERCISE,
                Pedometer.EXERCISE_DISTANCE,
                Pedometer.EXERCISE_STEPS,
                Pedometer.EXERCISE_TIME,
                Pedometer.FAT_COMBUSTION,
                Pedometer.JOG_STEPS,
                Pedometer.JOG_TIME,
                Pedometer.MEASURE_STATUS,
                Pedometer.METS,
                Pedometer.STATUS,
                Pedometer.STEPS,
                Pedometer.TIME,
                Pedometer.WALK_STATUS,
                Pedometer.WALK_STEPS,
                Pedometer.WALK_TIME,
            };

        // Pedometerクラスの取得
        Pedometer pedometer = Pedometer.createInstance(this);    /* ★Addon用API使用箇所★ */

        // StringBufferを作成する
        StringBuffer nameStr = new StringBuffer();
        StringBuffer paramStr = new StringBuffer();
        int lengthOfParameter = key.length;
        boolean result;

        for(int i = 0; i < lengthOfParameter; i++) {
            // StringBufferに情報を入れていく
            nameStr.append(key[i]);
            nameStr.append("\n");

            // サポートの有無を取得
            result = pedometer.isSupported(key[i]);    /* ★Addon用API使用箇所★ */

            if(result) {
                // 対応している場合
                paramStr.append(": o");
            } else {
                // 非対応の場合
                paramStr.append(": x");
            }
            paramStr.append("\n");
        }
        // TextViewにStringBufferの内容を反映させる
        dataName.setText(nameStr.toString());
        dataParam.setText(paramStr.toString());
    }
}